==> cdk-cx-api-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/cxapi/CloudAssembly.java <==
package software.amazon.awscdk.cxapi;

/**
 * Represents a deployable cloud application.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:12:23.569Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.CloudAssembly")
public class CloudAssembly extends software.amazon.jsii.JsiiObject {

    protected CloudAssembly(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudAssembly(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Reads a cloud assembly from the specified directory.
     * 
     * EXPERIMENTAL
     * 
     * @param directory The root directory of the assembly. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CloudAssembly(final java.lang.String directory) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(directory, "directory is required") }));
    }

    /**
     * Returns a CloudFormation stack artifact from this assembly.
     * 
     * EXPERIMENTAL
     * 
     * @return a `CloudFormationStackArtifact` object.
     * @param stackName the name of the CloudFormation stack. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudFormationStackArtifact getStack(final java.lang.String stackName) {
        return this.jsiiCall("getStack", software.amazon.awscdk.cxapi.CloudFormationStackArtifact.class, new Object[] { java.util.Objects.requireNonNull(stackName, "stackName is required") });
    }

    /**
     * Returns the tree metadata artifact from this assembly.
     * 
     * EXPERIMENTAL
     * 
     * @return a `TreeCloudArtifact` object if there is one defined in the manifest, `undefined` otherwise.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.TreeCloudArtifact tree() {
        return this.jsiiCall("tree", software.amazon.awscdk.cxapi.TreeCloudArtifact.class);
    }

    /**
     * Attempts to find an artifact with a specific identity.
     * 
     * EXPERIMENTAL
     * 
     * @return A `CloudArtifact` object or `undefined` if the artifact does not exist in this assembly.
     * @param id The artifact ID. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudArtifact tryGetArtifact(final java.lang.String id) {
        return this.jsiiCall("tryGetArtifact", software.amazon.awscdk.cxapi.CloudArtifact.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * All artifacts included in this assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudArtifact> getArtifacts() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("artifacts", java.util.List.class));
    }

    /**
     * The root directory of the cloud assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getDirectory() {
        return this.jsiiGet("directory", java.lang.String.class);
    }

    /**
     * The raw assembly manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.AssemblyManifest getManifest() {
        return this.jsiiGet("manifest", software.amazon.awscdk.cxapi.AssemblyManifest.class);
    }

    /**
     * Runtime information such as module versions used to synthesize this assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.RuntimeInfo getRuntime() {
        return this.jsiiGet("runtime", software.amazon.awscdk.cxapi.RuntimeInfo.class);
    }

    /**
     * EXPERIMENTAL
     * 
     * @return all the CloudFormation stack artifacts that are included in this assembly.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudFormationStackArtifact> getStacks() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("stacks", java.util.List.class));
    }

    /**
     * The schema version of the assembly manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getVersion() {
        return this.jsiiGet("version", java.lang.String.class);
    }
}

==> cdk-cx-api-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/cxapi/CloudAssembly.java <==
package software.amazon.awscdk.cxapi;

/**
 * Represents a deployable cloud application.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:46.974Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.CloudAssembly")
public class CloudAssembly extends software.amazon.jsii.JsiiObject {

    protected CloudAssembly(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudAssembly(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Reads a cloud assembly from the specified directory.
     * 
     * EXPERIMENTAL
     * 
     * @param directory The root directory of the assembly. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CloudAssembly(final java.lang.String directory) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(directory, "directory is required") });
    }

    /**
     * Returns a CloudFormation stack artifact by name from this assembly.
     * 
     * @deprecated renamed to `getStackByName` (or `getStackArtifact(id)`)
     * @param stackName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public software.amazon.awscdk.cxapi.CloudFormationStackArtifact getStack(final java.lang.String stackName) {
        return this.jsiiCall("getStack", software.amazon.awscdk.cxapi.CloudFormationStackArtifact.class, new Object[] { java.util.Objects.requireNonNull(stackName, "stackName is required") });
    }

    /**
     * Returns a CloudFormation stack artifact from this assembly.
     * 
     * EXPERIMENTAL
     * 
     * @return a `CloudFormationStackArtifact` object.
     * @param artifactId the artifact id of the stack (can be obtained through `stack.artifactId`). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudFormationStackArtifact getStackArtifact(final java.lang.String artifactId) {
        return this.jsiiCall("getStackArtifact", software.amazon.awscdk.cxapi.CloudFormationStackArtifact.class, new Object[] { java.util.Objects.requireNonNull(artifactId, "artifactId is required") });
    }

    /**
     * Returns a CloudFormation stack artifact from this assembly.
     * 
     * EXPERIMENTAL
     * 
     * @return a `CloudFormationStackArtifact` object.
     * @param stackName the name of the CloudFormation stack. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudFormationStackArtifact getStackByName(final java.lang.String stackName) {
        return this.jsiiCall("getStackByName", software.amazon.awscdk.cxapi.CloudFormationStackArtifact.class, new Object[] { java.util.Objects.requireNonNull(stackName, "stackName is required") });
    }

    /**
     * Returns the tree metadata artifact from this assembly.
     * 
     * EXPERIMENTAL
     * 
     * @return a `TreeCloudArtifact` object if there is one defined in the manifest, `undefined` otherwise.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.TreeCloudArtifact tree() {
        return this.jsiiCall("tree", software.amazon.awscdk.cxapi.TreeCloudArtifact.class);
    }

    /**
     * Attempts to find an artifact with a specific identity.
     * 
     * EXPERIMENTAL
     * 
     * @return A `CloudArtifact` object or `undefined` if the artifact does not exist in this assembly.
     * @param id The artifact ID. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudArtifact tryGetArtifact(final java.lang.String id) {
        return this.jsiiCall("tryGetArtifact", software.amazon.awscdk.cxapi.CloudArtifact.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * All artifacts included in this assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudArtifact> getArtifacts() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("artifacts", java.util.List.class));
    }

    /**
     * The root directory of the cloud assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getDirectory() {
        return this.jsiiGet("directory", java.lang.String.class);
    }

    /**
     * The raw assembly manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.AssemblyManifest getManifest() {
        return this.jsiiGet("manifest", software.amazon.awscdk.cxapi.AssemblyManifest.class);
    }

    /**
     * Runtime information such as module versions used to synthesize this assembly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.RuntimeInfo getRuntime() {
        return this.jsiiGet("runtime", software.amazon.awscdk.cxapi.RuntimeInfo.class);
    }

    /**
     * EXPERIMENTAL
     * 
     * @return all the CloudFormation stack artifacts that are included in this assembly.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudFormationStackArtifact> getStacks() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("stacks", java.util.List.class));
    }

    /**
     * The schema version of the assembly manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getVersion() {
        return this.jsiiGet("version", java.lang.String.class);
    }
}
